<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Raccourcis cachés</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Ces raccourcis codés en dur seront remplacés s&apos;ils sont également affectés à d&apos;autres actions dans Préférences → Raccourcis.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Échap</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Fermer la fenêtre ou quitter le mode plein écran</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Image suivante</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Dernière image</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Image précédente</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Retour arrière</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation type="unfinished">Accueil</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Première image</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Démarrer en plein écran (peut être utile avec les gestionnaires de fenêtres en mosaïque)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Copie d&apos;écran (déprécié, utilisez screengrab à la place)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation type="unfinished">Répertoire</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Prendre une copie d&apos;écran et l&apos;enregistrer dans le répertoire sans l&apos;afficher (déconseillé, utilisez screengrab à la place)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FICHIER1, FICHIER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>réponse : erreur inconnue</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>réponse : erreur inconnue</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>réponse : erreur inconnue</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>A simple and fast image viewer</source>
        <translation>Une visionneuse d&apos;images simple et rapide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>LXQt Project</source>
        <translation>LXQt Project</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Development: </source>
        <translation>Développement&#xa0;: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Author: </source>
        <translation>Auteur&#xa0;: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Image files (%1)</source>
        <translation>Fichier image (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Open directory</source>
        <translation>Ouvrir le répertoire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Save File</source>
        <translation>Enregistrer un fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="772"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Chargement...) - Visionneuse d&apos;images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="778"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Échec de chargement) - Visionneuse d&apos;images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visionneuse d&apos;images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visionneuse d&apos;images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1322"/>
        <source>EXIF Data</source>
        <translation>Données EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Effacer</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Utiliser une touche de modification pour effacer un raccourci
en mode édition.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="334"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Avertissement : raccourci ambigu détecté!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="351"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Raccourcis ambigus non acceptés.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Impossible d&apos;enregistrer avec ce format d&apos;image !</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Chemin :</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur (hébergement d&apos;images)</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB (hébergement d&apos;images)</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack (hébergement d&apos;images)</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visionneuse d&apos;images</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Fichiers récemment ouverts</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>A&amp;ide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Toolbar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <location filename="../mainwindow.ui" line="671"/>
        <source>Annotations Toolbar</source>
        <translation>Barre d&apos;annotations</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>O&amp;uvrir avec…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Raccourci&amp;s cachés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>&amp;Open…</source>
        <translation>&amp;Ouvrir…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Recharger le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Save</source>
        <translation>Enregi&amp;strer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Save &amp;As</source>
        <translation>E&amp;nregistrer sous</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Zoom &amp;In</source>
        <translation>Zoomer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;Out</source>
        <translation>Dézoomer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copier dans le presse-papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Next File</source>
        <translation>Fichier suivant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>PgDown</source>
        <translation>Bas de page</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Previous File</source>
        <translation>Fichier précédent</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>PgUp</source>
        <translation>Haut de page</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>Original Size</source>
        <translation>Taille d&apos;origine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Fit</source>
        <translation>Adapter la &amp;taille</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Rotation horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rotation &amp;anti-horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>P&amp;references</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>First File</source>
        <translation>Premier fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Home</source>
        <translation>Accueil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Last File</source>
        <translation>Dernier fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Retournement &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Capture Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Flip &amp;Vertically</source>
        <translation>Retournement &amp;vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Coller depuis le presse-papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaporama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <source>Show Thumbnails</source>
        <translation>Afficher les miniatures</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>File Properties</source>
        <translation>Propriétés du fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>Open &amp;Directory</source>
        <translation>Ouvrir &amp;répertoire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Upload</source>
        <translation>Transférer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Upload the image</source>
        <translation>Transférer l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Show EXIF Data</source>
        <translation>Afficher les données EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>No Tool</source>
        <translation>Aucun outil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Deselect all drawing tools</source>
        <translation>Désélectionner tous les outils de dessin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Draw Arrow</source>
        <translation>Dessiner flèche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw an arrow</source>
        <translation>Dessiner une flèche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw Rectangle</source>
        <translation>Dessiner rectangle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw a hollow rectangle</source>
        <translation>Dessiner un rectangle creux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw Circle</source>
        <translation>Dessiner cercle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw a hollow circle</source>
        <translation>Dessiner un cercle creux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw Number</source>
        <translation>Dessiner nombre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="635"/>
        <source>Draw incrementing numbers</source>
        <translation>Dessiner des nombres incrémentants</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Menubar</source>
        <translation>Barre de menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="649"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>&amp;Main Toolbar</source>
        <translation>Barre d&apos;outils principale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Main Toolbar</source>
        <translation>Barre d&apos;outils principale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Barre d&apos;outils d&apos;annotation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="679"/>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Show Outline</source>
        <translation>Afficher les contours</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>O</source>
        <translation>O.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copier le c&amp;hemin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Copy path</source>
        <translation>Copier le chemin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="710"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Resize</source>
        <translation>Redimensionner</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Thème des icônes :</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Limite de taille du fichier de miniature&#xa0;:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensions de l&apos;image de miniature&#xa0;:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Utiliser la corbeille du système (et ne pas demander)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Afficher le dock de données Exif par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Afficher la barre de menus par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Afficher la barre d&apos;outils principale par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Couleur de fond normale :</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Couleur de fond en plein écran :</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Nombre maximum de fichiers récents :</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervalle entre les diapositives (en secondes) :</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>Show image outline by default</source>
        <translation>Afficher les contours de l&apos;image par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Afficher la barre d&apos;outils d&apos;annotations par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Fit images when navigating</source>
        <translation>Ajuster les images lors de la navigation</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> Mio</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Afficher les miniatures du dock par défaut</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="207"/>
        <source>Smooth images on zooming</source>
        <translation>Lisser les images en zoomant</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="234"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="239"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="247"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Redimensionner l&apos;image</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Taille actuelle :</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Nouvelle taille :</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Conserver les proportions</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Prendre une capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Région</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Écran entier</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Fenêtre actuelle seulement</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Capturer une zone de l&apos;écran</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclure le pointeur de la souris</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Délai :</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclure le titre et le cadre de la fenêtre</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Transférer</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
</context>
</TS>
